# Generated by Django 4.1.7 on 2024-06-26 14:37

from django.db import migrations, models
from django.db.models import Exists, OuterRef

from arkindex.process.models import FeatureUsage


def migrate_gpu_usage(apps, schema):
    WorkerRun = apps.get_model("process", "WorkerRun")
    # For versions that require GPUs, WorkerRuns should always use a GPU.
    WorkerRun.objects.filter(version__gpu_usage=FeatureUsage.Required).update(use_gpu=True)
    # For versions that support GPUs, only use a GPU on processes where GPU usage was enabled.
    # This replicates the previous behavior with process-wide GPU usage.
    WorkerRun.objects.filter(version__gpu_usage=FeatureUsage.Supported, process__use_gpu=True).update(use_gpu=True)

def reverse(apps, schema):
    Process = apps.get_model("process", "Process")
    WorkerRun = apps.get_model("process", "WorkerRun")
    Process.objects.update(use_gpu=Exists(WorkerRun.objects.filter(process_id=OuterRef("pk"), use_gpu=True)))


class Migration(migrations.Migration):

    dependencies = [
        ("process", "0036_alter_process_name"),
    ]

    operations = [
        migrations.AddField(
            model_name="workerrun",
            name="use_gpu",
            field=models.BooleanField(default=False),
        ),
        migrations.RunPython(
            migrate_gpu_usage,
            reverse_code=reverse,
            elidable=True,
        ),
        migrations.RemoveField(
            model_name="process",
            name="use_gpu"
        )
    ]
